Hooks:PostHook(WeaponTweakData, "_init_new_weapons", "flipturn_data", function(self, params)
--[[
DYNAMIC VIEWMODEL SHIFTING WHILE RELOADING
the code can take "not_empty" and/or "empty" reloads
each reload can take "ads" and/or "hip" stances
however, you can't access any ADS reloads without a mod to enable ADS while reloading e.g. IREnFIST

self.wpnname.reload_timed_stance_mod = {
	non_empty = {
		hip = {},
		ads = {}
	},
	empty = {
		hip = {},
		ads = {}
	}
}

can also be set on weapon parts in weaponfactorytweakdata
self.new_m4.wpn_fps_m4_uupg_b_long.custom_stats = {
	set_reload_timed_stance_mod = {
		empty = {
			hip = {
				{t = 0.8, translation = Vector3(-22, 0, -5), rotation = Rotation(-20, 0, -30), speed = 0.5},
				{t = 0.0, translation = Vector3(0, 0, 0), rotation = Rotation(0, 0, 0), speed = 0.5}
			}
		}
	}
}

t is time offset from END of reload in seconds
translation and rotation are position and rotation offsets, this is familiar if you've ever touched stance_mod shit
speed is how quickly/slowly the weapon should move while changing stance_mod
sound can now be specified to play a sound
--]]

-- this data assumes unmodified reload timers
self.new_m4.reload_timed_stance_mod = {
	empty = {
		hip = {
			{t = 0.8, translation = Vector3(-22, 0, -5), rotation = Rotation(-20, 0, -30), speed = 0.5}, -- turn gun over to check that bolt has released
			{t = 0.0, translation = Vector3(0, 0, 0), rotation = Rotation(0, 0, 0), speed = 0.5} -- return to default position
		}
	}
}

-- copy the flipturn over to some other weapons that use CAR-4 animations
if self.bajur then
	self.bajur.reload_timed_stance_mod = deep_clone(self.new_m4.reload_timed_stance_mod)
end
if self.hk416 then
	self.hk416.reload_timed_stance_mod = deep_clone(self.new_m4.reload_timed_stance_mod)
end
if self.drongo then
	self.drongo.reload_timed_stance_mod = deep_clone(self.new_m4.reload_timed_stance_mod)
end
if self.acwr2 then
	self.acwr2.reload_timed_stance_mod = deep_clone(self.new_m4.reload_timed_stance_mod)
end


--[[
DYNAMIC VIEWMODEL SHIFTING AFTER FIRING
the t here is time after firing in seconds (like anyone would fucking expect, rather than the ass-backwards thing i did for reload shifts)

self.welrod.fire_timed_stance_mod = {
	ads = {
		{t = 0, translation = Vector3(0, -10, -5), rotation = Rotation(0, 10, 0), speed = 2},
		{t = 0.15, translation = Vector3(0, -5, -40), rotation = Rotation(0, 30, 20), speed = 2},
		{t = 0.30, translation = Vector3(0, -10, -40), rotation = Rotation(0, 32, 20), speed = 2, sound = "wp_msr_lever_pull"},
		{t = 0.60, translation = Vector3(0, -5, -40), rotation = Rotation(0, 30, 20), speed = 2, sound = "wp_msr_lever_release"},
		{t = 0.80, translation = Vector3(0, 0, 0), rotation = Rotation(0, 0, 0), speed = 1}
	},
	hip = {
		{t = 0, translation = Vector3(0, -10, -5), rotation = Rotation(0, 10, 0), speed = 2},
		{t = 0.15, translation = Vector3(0, -5, -30), rotation = Rotation(10, -10, -70), speed = 2},
		{t = 0.30, translation = Vector3(0, -10, -30), rotation = Rotation(10, -8, -70), speed = 2, sound = "wp_msr_lever_pull"},
		{t = 0.60, translation = Vector3(0, -5, -30), rotation = Rotation(10, -10, -70), speed = 2, sound = "wp_msr_lever_release"},
		{t = 0.80, translation = Vector3(0, 0, 0), rotation = Rotation(0, 0, 0), speed = 1}
	}
}

can also be set on weapon parts in weaponfactorytweakdata
self.parts.wpn_fps_upg_jfhjsalkjdklsa.custom_stats = {
	set_fire_timed_stance_mod = {
		ads = {
			{t = 0, translation = Vector3(0, -10, -5), rotation = Rotation(0, 10, 0), speed = 2},
			{t = 0.15, translation = Vector3(0, -5, -40), rotation = Rotation(0, 30, 20), speed = 2},
			{t = 0.30, translation = Vector3(0, -10, -40), rotation = Rotation(0, 32, 20), speed = 2, sound = "wp_msr_lever_pull"},
			{t = 0.60, translation = Vector3(0, -5, -40), rotation = Rotation(0, 30, 20), speed = 2, sound = "wp_msr_lever_release"},
			{t = 0.80, translation = Vector3(0, 0, 0), rotation = Rotation(0, 0, 0), speed = 1}
		},
		hip = {
			{t = 0, translation = Vector3(0, -10, -5), rotation = Rotation(0, 10, 0), speed = 2},
			{t = 0.15, translation = Vector3(0, -5, -30), rotation = Rotation(10, -10, -70), speed = 2},
			{t = 0.30, translation = Vector3(0, -10, -30), rotation = Rotation(10, -8, -70), speed = 2, sound = "wp_msr_lever_pull"},
			{t = 0.60, translation = Vector3(0, -5, -30), rotation = Rotation(10, -10, -70), speed = 2, sound = "wp_msr_lever_release"},
		}
	}
}
--]]

--[[
DYNAMIC VIEWMODEL SHIFTING WITH AMMO COUNT
shifts viewmodel depending on current ammo
intended for shotguns e.g. tilting to load the right-side tube instead of the left-side tube on a UTS-15
first entry is for 0 ammo, second entry for 1 ammo, etc

self.serbu.shotgun_ammo_stance_mod = {
	hip = {
		{translation = Vector3(0, 0, 0), rotation = Rotation(0, 0, -100), speed = 5, sound = "wp_msr_lever_pull"},
		{translation = Vector3(0, 0, 0), rotation = Rotation(0, 0, -80), speed = 5},
		{translation = Vector3(0, 0, 0), rotation = Rotation(0, 0, -60), speed = 5, sound = "wp_msr_lever_pull"},
		{translation = Vector3(0, 0, 0), rotation = Rotation(0, 0, -40), speed = 5},
		{translation = Vector3(0, 0, 0), rotation = Rotation(0, 0, -20), speed = 5, sound = "wp_msr_lever_pull"}
	},
	ads = {
		{translation = Vector3(-5, 0, 0), rotation = Rotation(0, 0, 0), speed = 5},
		{translation = Vector3(5, 0, 0), rotation = Rotation(0, 0, 0), speed = 5},
		{translation = Vector3(-5, 0, 0), rotation = Rotation(0, 0, 0), speed = 5},
		{translation = Vector3(5, 0, 0), rotation = Rotation(0, 0, 0), speed = 5},
		{translation = Vector3(-5, 0, 0), rotation = Rotation(0, 0, 0), speed = 5}
	}
}
--]]
end)